@@ -28,9 +28,10 @@
 
 typedef struct _YelpManParser YelpManParser;
 
-YelpManParser *     yelp_man_parser_new          (void);
-xmlDocPtr           yelp_man_parser_parse_file   (YelpManParser   *parser,
-						  gchar           *file);
-void                yelp_man_parser_free         (YelpManParser   *parser);
+YelpManParser *     yelp_man_parser_new         (void);
+xmlDocPtr           yelp_man_parser_parse_file  (YelpManParser   *parser,
+						 gchar           *file,
+						 const gchar     *encoding);
+void                yelp_man_parser_free        (YelpManParser   *parser);
 
 #endif /* __YELP_MAN_PARSER_H__ */
